@@ -1,11 +1,12 @@
 from .Image import Image
 from .Meta import Meta, TrainingMeta, EvaluationMeta
-from .Model import Model
+from .Model import Model, EvaluationModel
 
 __all__ = [
     Image,
     Meta,
     Model,
+    EvaluationModel,
     TrainingMeta,
     EvaluationMeta
 ]
